Skip to contents

mmrm_ is a wrapper function of mmrm::mmrm to create an object to be passed into jointCovariance, the main function of this package through its argument .... The object defines how a MMRM model would be fitted.

Usage

mmrm_(
  formula,
  covariance = NULL,
  reml = TRUE,
  control = mmrm::mmrm_control(...),
  ...,
  data_index = 1
)

Arguments

formula

see formula in mmrm::mmrm.

covariance

see covariance in mmrm::mmrm.

reml

see reml in mmrm::mmrm.

control

see control in mmrm::mmrm.

...

see ... in mmrm::mmrm.

data_index

integer. Index of the data frame in the data argument of jointCovariance to be used when fitting a GEE model.

Details

The argument weights of mmrm::mmrm is supported in mmrm_ due to the complexity in handling environment and scope.

Please always refer to help document of mmrm::mmrm before using mmrm_. For example, time variable and observation ID must be factor variables in some cases, otherwise error may be prompted. Users can call mmrm::mmrm using the same arguments being passed to mmrm_ to check validity.