coxph_ is a wrapper function of survival::coxph to create an object to be
passed into jointCovariance, the main function of this package through its
argument .... The object defines how a proportional hazard model would be
fitted.
Arguments
- formula
see
formulainsurvival::coxph.- data_index
integer. Index of the data frame in the
dataargument ofjointCovarianceto be used when fitting a proportional hazards model.
Details
Not all arguments of survival::coxph are supported in coxph_ due to the
complexity in handling environment and scope, which is particularly difficult
for arguments like weights, subset, etc.