logrank_ is a wrapper function survival::coxph to create an object to be
passed into jointCovariance, the main function of this package through its
argument .... Logrank test is the score test under the proportional hazards
regression model. The object defines how a logrank test would be computed.
Usage
logrank_(formula, ties = c("efron", "breslow", "exact"), data_index = 1)Arguments
- formula
see
formulainsurvival::coxph.- ties
character string specifying the method for tie handling. One of
"efron"(default),"breslow", or"exact". Passed through tosurvival::coxph.- data_index
integer. Index of the data frame in the
dataargument ofjointCovarianceto be used when computing testing statistic of logrank test.
Details
Not all arguments of survival::coxph are supported in logrank_ due to the
complexity in handling environment and scope, which is particularly difficult
for arguments like weights, subset, etc.