Calculate Variance-Covariance Matrix for a Fitted Model Object
Source:R/vcov.jointCovariance.R
vcov.jointCovariance.RdReturns the variance-covariance matrix of the main parameters of fitted model
objects. The "main" parameters of models correspond to those returned by coef.
Usage
# S3 method for class 'jointCovariance'
vcov(object, model_index = NULL, ...)Arguments
- object
an object returned by
jointCovariance().- model_index
NULLif displaying covariance matrix of all fitted models; otherwise, an integer indicating the fitted model.- ...
for debugging only